Module capabilities

Module capabilities 

Handles Management of Capabilities

Traits

CapabilityExt

Functions

drop_privileges
Drop any extra granted capabilities, and reset to defaults which are in oci specification
reset_effective
reset capabilities of process calling this to effective capabilities effective capability set is set of capabilities used by kernel to perform checks see https://man7.org/linux/man-pages/man7/capabilities.7.html for more information