pub struct InitContainerBuilder { /* private fields */ }Implementations
Sourceimpl InitContainerBuilder
impl InitContainerBuilder
Sourcepub fn with_systemd(self, should_use: bool) -> Self
pub fn with_systemd(self, should_use: bool) -> Self
Sets if systemd should be used for managing cgroups
Sourcepub fn as_sibling(self, as_sibling: bool) -> Self
pub fn as_sibling(self, as_sibling: bool) -> Self
Sets if the init process should be run as a child or a sibling of the calling process
pub fn with_detach(self, detached: bool) -> Self
pub fn with_no_pivot(self, no_pivot: bool) -> Self
Sourcepub fn build(self) -> Result<Container, LibcontainerError>
pub fn build(self) -> Result<Container, LibcontainerError>
Creates a new container