Module wrapper

Module wrapper 

Enums

ClientWrapper
Enum wrapper for different client types The Client trait contains generic methods, which makes it impossible to use as a trait object. Therefore, we define ClientWrapper as an enum-based dynamic dispatch to handle this.

Functions

create_network_client