ContainerArgs

Struct ContainerArgs 

pub struct ContainerArgs {
Show 18 fields pub container_type: ContainerType, pub syscall: SyscallType, pub spec: Rc<Spec>, pub rootfs: PathBuf, pub console_socket: Option<RawFd>, pub notify_listener: NotifyListener, pub preserve_fds: i32, pub container: Option<Container>, pub user_ns_config: Option<UserNamespaceConfig>, pub cgroup_config: CgroupConfig, pub detached: bool, pub executor: Box<dyn Executor>, pub no_pivot: bool, pub stdin: Option<RawFd>, pub stdout: Option<RawFd>, pub stderr: Option<RawFd>, pub as_sibling: bool, pub pid_file: Option<PathBuf>,
}

Fields

container_type: ContainerType

Indicates if an init or a tenant container should be created

syscall: SyscallType

Interface to operating system primitives

spec: Rc<Spec>

OCI compliant runtime spec

rootfs: PathBuf

Root filesystem of the container

console_socket: Option<RawFd>

Socket to communicate the file descriptor of the ptty

notify_listener: NotifyListener

The Unix Domain Socket to communicate container start

preserve_fds: i32

File descriptors preserved/passed to the container init process.

container: Option<Container>

Container state

user_ns_config: Option<UserNamespaceConfig>

Options for new namespace creation

cgroup_config: CgroupConfig

Cgroup Manager Config

detached: bool

If the container is to be run in detached mode

executor: Box<dyn Executor>

Manage the functions that actually run on the container

no_pivot: bool

If do not use pivot root to jail process inside rootfs

stdin: Option<RawFd>stdout: Option<RawFd>stderr: Option<RawFd>as_sibling: boolpid_file: Option<PathBuf>

File path used to communicate the PID of the container process to the higher-level runtime.