pub struct MainReceiver { /* private fields */ }Implementations
Sourceimpl MainReceiver
impl MainReceiver
Sourcepub fn wait_for_intermediate_ready(&mut self) -> Result<Pid, ChannelError>
pub fn wait_for_intermediate_ready(&mut self) -> Result<Pid, ChannelError>
Waits for associated intermediate process to send ready message and return the pid of init process which is forked by intermediate process
pub fn wait_for_mapping_request(&mut self) -> Result<(), ChannelError>
pub fn wait_for_seccomp_request(&mut self) -> Result<i32, ChannelError>
pub fn wait_for_network_setup_ready(&mut self) -> Result<(), ChannelError>
Sourcepub fn wait_for_init_ready(&mut self) -> Result<(), ChannelError>
pub fn wait_for_init_ready(&mut self) -> Result<(), ChannelError>
Waits for associated init process to send ready message and return the pid of init process which is forked by init process
pub fn wait_for_hook_request(&mut self) -> Result<(), ChannelError>
pub fn close(&self) -> Result<(), ChannelError>