Module intel_rdt

Module intel_rdt 

Enums

IntelRdtError
ParseLineError

Functions

delete_resctrl_subdirectory
find_resctrl_mount_point
Finds the resctrl mount path by looking at the process mountinfo data.
setup_intel_rdt
Sets up Intel RDT configuration for the container process based on the OCI config. The result bool tells whether or not we need to clean up the created subdirectory.