Module syscall

Module syscall 

An interface trait so that rest of Youki can call necessary functions without having to worry about their implementation details

Enums

SyscallType

Traits

Syscall
This specifies various kernel/other functionalities required for container management

Functions

create_syscall