Module user_ns

Module user_ns 

Structs

UserNamespaceConfig
UserNamespaceIDMapper

Enums

MappingError
UserNamespaceError
ValidateSpecError

Functions

lookup_map_binaries
Looks up the location of the newuidmap and newgidmap binaries which are required to write multiple user/group mappings
unprivileged_user_ns_enabled