lookup_map_binaries

Function lookup_map_binaries 

pub fn lookup_map_binaries(
    spec: &Linux,
) -> Result<Option<(PathBuf, PathBuf)>, MappingError>
Looks up the location of the newuidmap and newgidmap binaries which are required to write multiple user/group mappings