pub struct DefaultExecutor {}Trait Implementations
Sourceimpl Clone for DefaultExecutor
impl Clone for DefaultExecutor
Sourcefn clone(&self) -> DefaultExecutor
fn clone(&self) -> DefaultExecutor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Executor for DefaultExecutor
impl Executor for DefaultExecutor
Sourcefn validate(&self, spec: &Spec) -> Result<(), ExecutorValidationError>
fn validate(&self, spec: &Spec) -> Result<(), ExecutorValidationError>
Validate if the spec can be executed by the executor. This step runs
after the container init process is created, entered into the correct
namespace and cgroups, and pivot_root into the rootfs. But this step
runs before waiting for the container start signal.
Sourcefn setup_envs(
&self,
envs: HashMap<String, String>,
) -> Result<(), ExecutorSetEnvsError>
fn setup_envs( &self, envs: HashMap<String, String>, ) -> Result<(), ExecutorSetEnvsError>
Set environment variables for the container process to be executed.
This step runs after the container init process is created, entered
into the correct namespace and cgroups, and pivot_root into the rootfs.
But this step runs before waiting for the container start signal.
The host’s environment variables are not cleared yet at this point.
They should be cleared explicitly if needed.