pub fn reset_effective<S: Syscall + ?Sized>(
syscall: &S,
) -> Result<(), SyscallError>Expand description
reset capabilities of process calling this to effective capabilities effective capability set is set of capabilities used by kernel to perform checks see https://man7.org/linux/man-pages/man7/capabilities.7.html for more information