Module container

Module container 

Container management

Re-exports

pub use state::ContainerProcessState;Deprecated
pub use state::ContainerStatus;
pub use state::State;
pub use state::StateConversionError;

Modules

builder
This crate is responsible for the creation of containers. It provides a builder that can be used to configure and create containers. We distinguish between an init container for which namespaces and cgroups will be created (usually) and a tenant container process that will move into the existing namespaces and cgroups of the initial container process (e.g. used to implement the exec command).
init_builder
state
Information about status and state of the container
tenant_builder

Structs

CheckpointOptions
Checkpoint parameter structure
Container
Structure representing the container data

Enums

CheckpointError