Module libcontainer::container
source · Expand description
Container management
Re-exports
pub use state::ContainerProcessState;pub use state::ContainerStatus;pub use state::State;
Modules
- This crate is responsible for the creation of containers. It provides a builder that can be used to configure and create containers. We distinguish between an init container for which namespaces and cgroups will be created (usually) and a tenant container process that will move into the existing namespaces and cgroups of the initial container process (e.g. used to implement the exec command).
- Information about status and state of the container
Structs
- Checkpoint parameter structure
- Structure representing the container data