pub fn setup_addresses_in_network_namespace(
addrs: &[CidrAddress],
link_index: u32,
new_name: &str,
addr_client: &mut AddressClient,
) -> Result<(), NetworkError>Expand description
Core logic for setting up addresses in the new network namespace This function is extracted to make it testable without system calls
Note: The addresses passed to this function are already filtered in the main process to include only global scope and permanent addresses.