Enums
- Client
Wrapper - Enum wrapper for different client types
The
Clienttrait contains generic methods, which makes it impossible to use as a trait object. Therefore, we defineClientWrapperas an enum-based dynamic dispatch to handle this.
Client trait contains generic methods, which makes it impossible to use as a trait object.
Therefore, we define ClientWrapper as an enum-based dynamic dispatch to handle this.