pub fn setup_intel_rdt(
maybe_container_id: Option<&str>,
init_pid: &Pid,
intel_rdt: &LinuxIntelRdt,
) -> Result<bool, IntelRdtError>Expand description
Sets up Intel RDT configuration for the container process based on the OCI config. The result bool tells whether or not we need to clean up the created subdirectory.