Mount

Struct Mount 

pub struct Mount { /* private fields */ }

Implementations

Source

impl Mount

pub fn new() -> Mount

pub fn with_mountinfo_provider<P: MountInfoProvider + 'static>( self, provider: P, ) -> Self

pub fn setup_mount( &self, mount: &SpecMount, options: &MountOptions<'_>, ) -> Result<(), MountError>

pub fn make_parent_mount_private( &self, rootfs: &Path, ) -> Result<MountInfo, MountError>

Make parent mount of rootfs private if it was shared, which is required by pivot_root. It also makes sure following bind mount does not propagate in other namespaces.

pub fn check_proc_mount( &self, rootfs: &Path, mount: &SpecMount, ) -> Result<(), MountError>

check_proc_mount checks to ensure that the mount destination is not over the top of /proc. dest is required to be an abs path and have any symlinks resolved before calling this function.

Example (a valid case where /proc is mounted with proc type.)
use std::path::PathBuf;
use oci_spec::runtime::MountBuilder as SpecMountBuilder;
use libcontainer::rootfs::Mount;

let mounter = Mount::new();

let rootfs = PathBuf::from("/var/lib/my-runtime/containers/abcd1234/rootfs");
let destination = PathBuf::from("/proc");
let source = PathBuf::from("proc");
let typ = "proc";

let mount = SpecMountBuilder::default()
    .destination(destination)
    .typ(typ)
    .source(source)
    .build()
    .expect("failed to build SpecMount");

assert!(mounter.check_proc_mount(rootfs.as_path(), &mount).is_ok());
Example (bind mount to /proc that should fail)
use std::path::PathBuf;
use oci_spec::runtime::MountBuilder as SpecMountBuilder;
use libcontainer::rootfs::Mount;

let mounter = Mount::new();

let rootfs = PathBuf::from("/var/lib/my-runtime/containers/abcd1234/rootfs");
let destination = PathBuf::from("/proc");
let source = PathBuf::from("/tmp");
let typ = "bind";

let mount = SpecMountBuilder::default()
    .destination(destination)
    .typ(typ)
    .source(source)
    .build()
    .expect("failed to build SpecMount");

assert!(mounter.check_proc_mount(rootfs.as_path(), &mount).is_err());