Contains a wrapper of syscalls for unit tests This provides a uniform interface for rest of Youki to call syscalls required for container management
Re-exports
pub use syscall::Syscall;
Modules
- linux
- Implements Command trait for Linux systems
- syscall
- An interface trait so that rest of Youki can call necessary functions without having to worry about their implementation details
- test