Module user_ns
libcontainer
0.5.7
Module user_ns
Module Items
Structs
Enums
Functions
In crate libcontainer
libcontainer
Module
user_ns
Structs

User
Namespace
Config
User
NamespaceID
Mapper
Enums

Mapping
Error
User
Namespace
Error
Validate
Spec
Error
Functions

lookup_
map_
binaries
Looks up the location of the newuidmap and newgidmap binaries which are required to write multiple user/group mappings
unprivileged_
user_
ns_
enabled