Utility functionality
Enums
Traits
Functions
- create_
dir_ all - create_
dir_ all_ with_ mode - Creates the specified directory and all parent directories with the specified mode. Ensures that the directory has been created with the correct mode and that the owner of the directory is the owner that has been specified
- get_
cgroup_ path - If None, it will generate a default path for cgroups.
- get_
unix_ user - Get a nix::unistd::User via UID. Potential errors will be ignored.
- get_
user_ home - Get home path of a User via UID.
- is_
in_ new_ userns - open
- parse_
env - retry
- rootless_
required - Checks if rootless mode needs to be used
- validate_
mount_ options - Validates mount destinations and warns about deprecated relative paths. Follows the OCI Runtime Spec requirement that mount destinations SHOULD be absolute. Relative paths are deprecated but still accepted for backward compatibility.
- validate_
spec_ for_ net_ devices - validate_
spec_ for_ new_ user_ ns - checks if given spec is valid for current user namespace setup
- verify_
inode - Verify file descriptor using stat and statfs, similar to runc’s VerifyInode.
- write_
file