Module libcontainer::utils
source · Expand description
Utility functionality
Enums
Traits
Functions
- Creates the specified directory and all parent directories with the specified mode. Ensures that the directory has been created with the correct mode and that the owner of the directory is the owner that has been specified
- If None, it will generate a default path for cgroups.
- Get a nix::unistd::User via UID. Potential errors will be ignored.
- Get home path of a User via UID.
- Checks if rootless mode needs to be used
- checks if given spec is valid for current user namespace setup